﻿using System;
using System.Windows;

namespace TestLibrary
{
    /// <summary>
    /// UI 헬퍼
    /// </summary>
    public static class UIHelper
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 의존 속성 등록하기 - RegisterDependencyProperty(defaultValue, affectsRender, affectsMeasure, affectsArrange, inherits, propertyChangedCallback, propertyName, propertyType, ownerType, validateValueCallback)

        /// <summary>
        /// 의존 속성 등록하기
        /// </summary>
        /// <param name="defaultValue">디폴트 값</param>
        /// <param name="affectsRender">렌더링 영향 여부</param>
        /// <param name="affectsMeasure">크기 측정 영향 여부</param>
        /// <param name="affectsArrange">배치 영향 여부</param>
        /// <param name="inherits">상속 여부</param>
        /// <param name="propertyChangedCallback">속성 변경 콜백</param>
        /// <param name="propertyName">속성명</param>
        /// <param name="propertyType">속성 타입</param>
        /// <param name="ownerType">소유자 타입</param>
        /// <param name="validateValueCallback">값 무결성 콜백</param>
        /// <returns>의존 속성</returns>
        public static DependencyProperty RegisterDependencyProperty
        (
            object                  defaultValue,
            bool                    affectsRender,
            bool                    affectsMeasure,
            bool                    affectsArrange,
            bool                    inherits,
            PropertyChangedCallback propertyChangedCallback,
            string                  propertyName,
            Type                    propertyType,
            Type                    ownerType,
            ValidateValueCallback   validateValueCallback
        )
        {
            FrameworkPropertyMetadata frameworkPropertyMetadata = new FrameworkPropertyMetadata();

            frameworkPropertyMetadata.DefaultValue   = defaultValue;
            frameworkPropertyMetadata.AffectsRender  = affectsRender;
            frameworkPropertyMetadata.AffectsMeasure = affectsMeasure;
            frameworkPropertyMetadata.AffectsArrange = affectsArrange;
            frameworkPropertyMetadata.Inherits       = inherits;

            frameworkPropertyMetadata.PropertyChangedCallback += propertyChangedCallback;

            return DependencyProperty.Register(propertyName, propertyType, ownerType, frameworkPropertyMetadata, validateValueCallback);
        }

        #endregion
    }
}